/* ver.A.04.03(ASTROBOY) */


#include "version.h"


VERSION ap_version = {
	"AP.code",
	"pdbstatus",
	"(C) 2000-2004 Hirohisa Mori And GB-group",
	"ver.A.04.03(ASTROBOY)",
	2004,3,26,
	0,
	"pdb status checker ",
};

